<?php
/**
 * Copyright © 2015 FiloBlu. All rights reserved.
 */

namespace FiloBlu\Frau\Setup;

use \Magento\Eav\Setup\EavSetup;
use \Magento\Eav\Setup\EavSetupFactory;
use \Magento\Framework\Setup\ModuleDataSetupInterface as ModuleDataSetupInterface;
use \Magento\Framework\Setup\ModuleContextInterface;
use \Magento\Framework\Setup\UpgradeDataInterface;
use Magento\Eav\Model\Entity\Attribute\ScopedAttributeInterface as Attribute;

class UpgradeData implements UpgradeDataInterface
{
    protected $eavSetupFactory;

    public function __construct(EavSetupFactory $eavSetupFactory)
    {

        $this->eavSetupFactory = $eavSetupFactory;
    }

    public function upgrade(ModuleDataSetupInterface $setup, ModuleContextInterface $context)
    {
        if (!$context->getVersion()) {
            //no previous version found, installation, InstallSchema was just executed
            //be careful, since everything below is true for installation !
        }

        if (version_compare($context->getVersion(), '1.0.2') < 0) {
            $this->installAttributes($setup, $context);
        }
    }


    public function installAttributes($setup,$context){


        /** @var EavSetup $eavSetup */
        $eavSetup = $this->eavSetupFactory->create(['setup' => $setup]);

        // Add Text Attributes with scope GLOBAL
        $attributes = array('cod_modello','icons','ics2_description','volume');
        foreach ($attributes as $a) {
            $eavSetup->addAttribute(
                \Magento\Catalog\Model\Product::ENTITY,
                $a,
                [
                    'type' => 'varchar',
                    'label' => $a,
                    'input' => 'text',
                    'global' => Attribute::SCOPE_GLOBAL,
                    'visible' => true,
                    'required' => false,
                    'user_defined' => true,
                    'searchable' => false,
                    'filterable' => false,
                    'comparable' => false,
                    'visible_on_front' => false,
                    'used_in_product_listing' => false,
                    'unique' => false,
                    'group' => 'Product Attributes'
                ]
            );
        }

        // Add Text Attributes with scope STORE
        $attributes = array('accessories','article_composition');
        foreach ($attributes as $a) {
            $eavSetup->addAttribute(
                \Magento\Catalog\Model\Product::ENTITY,
                $a,
                [
                    'type' => 'varchar',
                    'label' => $a,
                    'input' => 'text',
                    'global' => Attribute::SCOPE_STORE,
                    'visible' => true,
                    'required' => false,
                    'user_defined' => true,
                    'searchable' => false,
                    'filterable' => false,
                    'comparable' => false,
                    'visible_on_front' => false,
                    'used_in_product_listing' => false,
                    'unique' => false,
                    'group' => 'Product Attributes'
                ]
            );
        }

        // Add Select Attributes
        $attributes = array('sole_height','greave_height','greave_circumference','wearability','insole','color','gender','line','season_sales','type_of_product','preferred_origin','made_in');
        foreach ($attributes as $a) {
            $eavSetup->addAttribute(
                \Magento\Catalog\Model\Product::ENTITY,
                $a,
                [
                    'type' => 'int',
                    'label' => $a,
                    'input' => 'select',
                    'global' => Attribute::SCOPE_GLOBAL,
                    'visible' => true,
                    'required' => false,
                    'user_defined' => true,
                    'searchable' => false,
                    'filterable' => false,
                    'comparable' => false,
                    'visible_on_front' => true,
                    'used_in_product_listing' => false,
                    'unique' => false,
                    'group' => 'Product Attributes'
                ]
            );
        }

    }

}
